########
chrisapp
########

The base module for Chris' plugin apps.

.. image:: https://badge.fury.io/py/chrisapp.svg
    :target: https://badge.fury.io/py/chrisapp

.. image:: https://travis-ci.org/FNNDSC/chrisapp.svg?branch=master
    :target: https://travis-ci.org/FNNDSC/chrisapp
